#
# spec file for package units
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2024 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without	units_cur
Name:           units
Version:        2.24
Release:        1.2
Summary:        Conversion Utility
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Physics
URL:            https://www.gnu.org/software/units/
Source0:        http://ftp.gnu.org/gnu/units/units-%{version}.tar.gz
Source1:        http://ftp.gnu.org/gnu/units/units-%{version}.tar.gz.sig
Source2:        https://savannah.gnu.org/people/viewgpg.php?user_id=33238#/%{name}.keyring
BuildRequires:  bison
BuildRequires:  readline-devel
%if %{with units_cur}
BuildRequires:  python3-base
Requires:       python3-requests
%endif

%description
The 'units' program converts quantities expressed in various scales to
their equivalents in other scales.

Units can also convert temperature values (Fahrenheit to Celsius, for
example) but this needs a slightly different input syntax. See the man
page for details.

%prep
%autosetup -p1

%build
export CFLAGS="%{optflags} -fPIE"
export LDFLAGS="-pie"
%configure
%make_build

%install
%make_install
ln -fsv ../../..%{_sharedstatedir}/units/currency.units %{buildroot}%{_datadir}/units
%{python3_fix_shebang}

%check
%make_build check

%files
%license COPYING
%{_bindir}/units
%{_datadir}/units
%dir %{_localstatedir}/lib/units
%{_localstatedir}/lib/units/currency.units
%{_localstatedir}/lib/units/cpi.units
%doc NEWS README
%{_infodir}/units.info%{?ext_info}
%{_mandir}/man1/units.1%{?ext_man}
%if %{with units_cur}
%{_bindir}/units_cur
%endif

%changelog
* Tue Nov 26 2024 Andreas Stieger <andreas.stieger@gmx.de>
- units 2.24:
  * Units definitions updated to reflect 2022 NIST CODATA.
  * Added ':=' assignment for interactively defined variables
  * Interactive variable definitions now appear in the log file
  * Added interactive "set" command to set or change options
  * Function additions for circles, diameters, wire gauges, pipes
* Mon Feb 26 2024 pgajdos@suse.com
- remove dependency on /usr/bin/python3 using
  %%python3_fix_shebang macro, [bsc#1212476]
* Mon Feb 19 2024 Andreas Stieger <andreas.stieger@gmx.de>
- units 2.23:
  * molarvolume changed to have dimensions of m^3/mol for
    consistency with NIST
  * Corrected erroneous definitions of moondist_min and
    moondist_max
  * Added atomic masses for all isotopes of all elements in
    elements.units
  * Added US Consumer Price index in cpi.units, which is updated
    monthly by units_cur.  Inflation calculations are possible with
    dollars_in() or inflation_since() and other related nonlinear
    units
  * Made exchangerate-api the default currency server
  * Adjusted US survey units to use the international foot by
  default due to deprecation of the US survey foot
  * abs() function works on units with dimensions, like -27 degrees.
  * Support unicode operators for division and multiplication
  * Ignore QUIT signal, which is sent by Ctrl-Backslash and Ctrl-4.
  * Suppress repeated unit values in display of unit definitions
  * Unit reductions that take more than 1000 steps now give a
    "circular reference" error.
  * More detailed reporting from the --check (-c) option.
  * Fixed bug in positioning pointer to errors in input when the
    input has leading spaces.
  * Fixed parser memory leak with numbers too large or small for
    type double.
  * Allow multiple divisions in expressions that start with "/",
    e.g. "/m/s"
* Sun Dec 25 2022 Andreas Stieger <andreas.stieger@gmx.de>
- units 2.22:
  * Fixed bug: segfault on inverse conversions of tables in verbose
    mode
  * Added support for ExchangeRate-API in units_cur
  * Minor unit definition fixes and updates, including updates to
    planetary data and a change in Rinfinity and hartree to
    increase accuracy.
  * Do not update currency.units at build
* Tue Jun  8 2021 pgajdos@suse.com
- require python3-requests [bsc#1186820]
* Thu Mar 11 2021 pgajdos@suse.com
- use python3 by home:lorenz
* Mon Nov 16 2020 Andreas Stieger <andreas.stieger@gmx.de>
- units 2.21:
  * Fix bug arising when some environment variables are undefined
  * Improve error reporting when input files are missing or invalid
- remove obsolete texinfo macros on Factory
- make the executable position independent
* Thu Oct  1 2020 Andreas Stieger <andreas.stieger@gmx.de>
- units 2.20:
  * Add abs(), ceil(), round(), floor(), Gamma(), lnGamma(),
    factorial(), erf() and erfc() functions.
  * Add densities of all of the elements
  * Add several new unit systems
  * Add --conformable option which noninteractively prints a list
    of all units conformable with a specified a specified unit
  * Invoke the pager more intelligently depending on the size of the
    screen
  * Fix bug where unit lists conversions displayed excess precision
    (e.g. non-integer output for integer input)
  * Display precision warning when conversion to unit lists uses
    all of the available precision
* Wed Jul 31 2019 Andreas Stieger <andreas.stieger@gmx.de>
- units 2.19:
  * Unit definitions updated to reflect new 2019 revisions to SI
    and the 2018 NIST CODATA.
  * Added definitions of country and USA state areas, and physical
    properties of selected woods.
  * Changes only to definitions.units in this release.
* Thu Oct 25 2018 astieger@suse.com
- units 2.18:
  * The units_cur script now supports multiple currency sources
  * Add hyperbolic functions: sinh, cosh, tanh, asinh, acosh, atanh
  * Add log to arbitrary integer bases: log3, log4, log72, etc.
  * Units can be redefined without a warning by adding '+' before
    the unit name in definitions.units.
  * Add 'quit' and 'exit' commands.
  * Add support for CGS electromagnetic units (activated using the
  - u option or the UNITS_SYSTEM environment variable)
  * Add !prompt command to add a prefix to the "You have:" prompt
  * Texts specified with !message appear in the log file
* Wed Jun 27 2018 astieger@suse.com
- units 2.17:
  * Updates to units database
  * Update units_cur to handle bad records returned by yahoo server
  * Move currency.units out of /usr/share because the file is not
    static and /usr/share is supposed to house static files.
    The new location is $sharedstatedir which may be /var/lib
* Wed Nov  1 2017 astieger@suse.com
- units 2.16:
  * Fix missing USD currency code (update to units_cur and
  definitions.units only).
- includes changes from 2.15:
  * The old timegenie service has vanished.  A new units_cur script
    uses yahoo.com server. The new script works directly in Python 2
    or Python 3 and no longer depends on unidecode.
  * Some currency definitions (e.g. currencies pegged to the euro)
    have moved out of definitions.units into currency.units.
  * Added bitcoin to currency.units
  * Fixed a memory leak bug for invalid exponent operations
* Mon Apr  3 2017 astieger@suse.com
- units 2.14:
  * Eliminated parser memory management limitation affecting long
    input expressions (e.g. a sum of more than 100 units)
  * Control characters are treated as white space rather than
    producing an error about invalid UTF-8.
* Thu Jun 23 2016 astieger@suse.com
- units 2.13:
  * Corrected error in heat of vaporization of water
  * Fixed bug where single character unicode prefixes couldn't
    combined with the second "s", so microsecond couldn't be
    abbreviated.
  * Fixed bug where -H '' option would write history to ~/.history.
  * Added -fpic compile option so that it is possible to compile to
    a library
* Thu Oct 15 2015 mpluskal@suse.com
- Update to 2.12
  * Updated and revised units database, with constants now based
    on 2014 CODATA.
  * Readline history is persistent and is saved to
    ~/.units_history, or to the file specified with --history (-H)
    option.
  * Fixed bug where '_' didn't give last result after conversion
    to function.
  * Fixed sporadic segmentation fault with --log.
  * Comments allowed on interactive input with '#', most useful
    with logging.
  * Added configure test for rl_completion_suppress_append, which
    helps compilation under MacOS.
  * Comment processing happens before checking UTF-8
    validity---comments are allowed to contain bogus UTF-8.
  * Changed units_cur to skip bogus precious metals data from
    timegenie and to skip currencies with no rate.
- Cleanups spec file with spec-cleaner
- Update usage of gpg signature
- Move info scriplet to preun
- Enable units_cur builiding by default
* Mon Apr  7 2014 andreas.stieger@gmx.de
- GNU Units 2.11:
  * Many long options didn't work
  * units_cur wouldn't print to stdout
* Sat Mar 29 2014 andreas.stieger@gmx.de
- install documentation files, including COPYING
* Thu Mar 27 2014 andreas.stieger@gmx.de
- GNU Units 2.10:
  * Added '_' to represent the previous result.
  * Added support for rational exponents with numerators larger
    than 1 so you can do calculations like liter^2|3.
  * Added logging with --log (-L) option.
  * Fixed some unit definitions (R_infinity, planckmass), and added
    R_K90 and K_J90 for the conventional values of the von Klitzing
    and Josephson constants.
  * Don't use readline unless reading from a tty.
  * Display of nonlinear unit definitions shows the range over which
    the unit is defined and the required dimensions of the argument.
  * Unit completion with readline will now complete nonlinear units,
    functions  (e.g. cuberoot), prefixes, and unit list aliases. It
    will no longer insert a space after the completion.
  * Running "units --version" returns success.
  * Combining "--version" with "--terse" gives a terse version
    output.
  * Combining "--version" with "--verbose" or running with "--info"
    gives a detailed output of how units was compiled and where its
    supporting files are found.
  * A nonlinear unit can be defined equal to another nonlinear unit
    using the syntax: "newfunc() oldfunc".
  * Domain and range specified with nonlinear units can be open
    intervals, indicated  by parentheses instead of brackets.
  * The "noerror" keyword on a nonlinear unit supresses error
    checking with "units --check" for that unit.
  * Changes to units_cur to work with timegenie changes and to
    support Python 3.
    The Python module unidecode is now required for units_cur.
  * The method for finding supporting files has changed when units
    is compiled to be relocatable.
  * Fix to compile with Bison 3.0.
  * Improved error messages for various cases.
  * Some simple icons are included.
- licence is GPL-3.0+
- run minimal unit tests
- spec file cleaning
- note that make install fails with smp_flags
- support optional build with units_cur for updating units
  (requires python-Unidecode, not in Factory)
* Mon Sep  9 2013 pgajdos@suse.com
- updated to version 2.02:
  * Added support for %%a and %%A output formats (hexadecimal floating point), and
    eliminated the restriction on the number of displayed digits when specifying
    an output format with the --output-format (-o) option.  Improved error
    handling for formats specified with --output-format.
  * Added --digits (-d) to specify the number of digits to display.  Giving
    '--digits max' (-dmax) will use the full available precision.
  * Added support for various Unicode minus sign symbols.  Units now treats the
    figure dash (U+2012), the en dash (U+2013), and the minus (U+2212) as
    identical to the ASCII hyphen/minus symbol (U+002D).
  * The !message command in units data files has been fixed so it does not
    produce output when the --quiet option is given.
  * Improved error handling when unit names end with numbers without a '_'.
  * Modified units_cur to work with XML format as the txt format disappeared.
  * Corrected error in definition of the nat.
  * Improved manual.
- employ gpg-offline
* Thu Nov  1 2012 pgajdos@suse.com
- updated to version 2.01:
  * Fixed error in electronmass
  * New definition for au
  * Fixed DESTDIR support for installation
  * Changed configure script for success with Solaris
  * Small changes to manual
- removed build.patch
* Tue Aug  7 2012 pgajdos@suse.com
- updated to version 2.00:
    General changes:
  * Unit lists provide conversion to sums of units (e.g. feet and inches).
  * Added --round (-r) and --show-factor (-S) options for use with unit lists.
  * Added unit lists aliases (e.g. time, usvol).
  * A python script, units_cur, can update currency data.
  * Units now flushes its output so you can talk to it with a pipe.
  * Units now works in UTF-8 if the system supports it.
  * Added --locale (-l) option to set the locale.
  * English units such as the gallon are defined in all locales, with US
    definitions by default except in the en_BG locale.  You can force
    the desired definition (Great Britain or US) by setting the
    environment variable UNITS_ENGLISH to GB or US.
  * Revised and extended the documentation, with more examples.
  * Added locale mapping to address Windows locale names.
  * Updated and revised units database, including UTF-8 definitions and
    the 2010 CODATA.
  * Fixed parsing bug for "1..2" or "1.2.3".  These now give an error.
  * Unit names can end with a number in the form of a subscript that
    starts with a '_', as in 'X_3'.
    Changes for units definition files:
  * Changed location and names of unit database, splitting off currency
    Files are /usr/local/share/units/{definitions,currency}.units and
    the personal units file is $HOME/.units instead of $HOME/units.dat.
  * Personal units filename can be changed with MYUNITSFILE environment variable.
  * Prefixes can be defined in any order: it is no longer necessary to
    define longer ones before shorter ones.
  * New definitions replace previous ones.  Personal units file is read
    after the system file rather than before.
  * Changed syntax for function definitions.  Instead of [in-unit,out-unit]
    you must now write units=[in-unit,out-unit].  Use 'units -c' to find
    places in your personal data files that need to be updated.
  * Add optional domain and range to function definitions with syntax
    domain=[min,max] and range=[min,max].  Either min or max can be
    omitted to signal infinity.
  * Unit list aliases can be defined with !unitlist command.
  * Added !var and !varnot and !endvar to include definitions based on
    environment variable settings.
  * Added !set to set environment variables (if they aren't already set).
  * Added !message to display a message
  * Data files are in UTF-8, with !utf8 and !endutf8 commands to mark
    definitions that require UTF-8 support.
  * Improved error handling when reading units.dat.
* Thu Aug 26 2010 pgajdos@suse.cz
- Updated to version 1.88
  * Updated units.dat
  * Fixed bug involving readline version 4.2
* Wed Feb 13 2008 schwab@suse.de
- Update to units 1.85.
  * Units reads ~/.units.dat if it exists before reading the standard
    units database.
  * Added support for ** as an exponent operator.
  * Type 'search text' to list units that contain 'text' in their name.
  * Precedence of '*' changed to match precedence of '/'.
    (Multiplication by juxtaposition retains a higher precedence than
    '/'.)  The --oldstar option selects the old precedence and --newstar
    forces the new precedence.
* Thu Mar 29 2007 schwab@suse.de
- Add bison to BuildRequires.
* Mon Dec  4 2006 schwab@suse.de
- Update to units 1.85.
  * Added --one-line (-1) option which causes the program to print only
    one line of output.
  * Added --compact option which causes the program to print only the
    conversion factors and a newline on output.
  * Added build support for DESTDIR.
  * Made minor changes that allow the program to be compiled into a
    library and linked with other programs.
  * Fixed bugs (including bus error on Intel Mac) and added
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sun May 22 2005 schwab@suse.de
- Update to units 1.85.
* Thu Oct  7 2004 schwab@suse.de
- Update to units 1.80.
* Fri Sep 10 2004 schwab@suse.de
- Fix missing declarations.
* Sat Apr 17 2004 schwab@suse.de
- Pacify autobuild.
* Fri Feb 27 2004 schwab@suse.de
- Add %%defattr.
* Thu Apr 17 2003 coolo@suse.de
- use BuildRoot
* Tue Jan 14 2003 nadvornik@suse.cz
- fixed multi-line string literals
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Thu Jun 13 2002 uli@suse.de
- update -> 1.74 (rewritten parser supports () for grouping,
  supports noninteger powers of numbers (e.g. 3^0.25), supports a bunch of
  functions (log, ln, log2, sin, cos, tan, exp) which can have units as
  arguments but they must reduce to dimensionless (e.g.
  log(watts/horsepower)), supports sqrt(unit) and cuberoot(unit), higher
  roots as unit^(1|4); functions can be defined in units.dat along with
  their inverse, and conversion to a function by specifying it's name alone
  as the "want" item; tables with linear interpolation)
* Thu Feb 22 2001 ro@suse.de
- added readline/readline-devel to neededforbuild (split from bash)
* Mon Sep 25 2000 uli@suse.de
- update -> 1.55
* Wed Mar  1 2000 schwab@suse.de
- Specfile cleanup, remove Makefile.Linux
- /usr/{info,man} -> /usr/share/{info,man}
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Wed Jan 22 1997 florian@suse.de
- first version of units 1.53
